import { __decorate, __metadata } from 'tslib';
import { EventEmitter, Input, Output, Component, ChangeDetectionStrategy, ViewChild, ViewChildren, forwardRef, QueryList, ChangeDetectorRef, ComponentFactoryResolver, ContentChildren, HostBinding, ViewContainerRef, NgModule } from '@angular/core';
import { FormGroup, ReactiveFormsModule } from '@angular/forms';
import { DynamicFormControlComponent, DynamicFormLayoutService, DynamicFormValidationService, DynamicCheckboxModel, DynamicDatePickerModel, DynamicFormGroupComponent, DynamicFormGroupModel, DynamicInputModel, DynamicRadioGroupModel, DynamicRatingModel, DynamicSelectModel, DynamicTextAreaModel, DynamicTimePickerModel, DynamicFormControlContainerComponent, DynamicFormComponentService, DynamicFormRelationService, DynamicTemplateDirective, DynamicFormArrayGroupModel, DynamicFormControlModel, DYNAMIC_FORM_CONTROL_TYPE_TIMEPICKER, DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA, DYNAMIC_FORM_CONTROL_TYPE_SELECT, DYNAMIC_FORM_CONTROL_TYPE_RATING, DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP, DYNAMIC_FORM_CONTROL_TYPE_INPUT, DYNAMIC_FORM_CONTROL_TYPE_GROUP, DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX, DYNAMIC_FORM_CONTROL_TYPE_ARRAY, DynamicFormArrayComponent, DynamicFormArrayModel, DynamicFormComponent, DynamicFormsCoreModule } from '@ng-dynamic-forms/core';
import { BsDatepickerDirective, BsDatepickerModule } from 'ngx-bootstrap/datepicker';
import { TimepickerComponent, TimepickerModule } from 'ngx-bootstrap/timepicker';
import { CommonModule } from '@angular/common';
import { RatingModule } from 'ngx-bootstrap/rating';
import { TextMaskModule } from 'angular2-text-mask';

let DynamicBootstrapCheckboxComponent = class DynamicBootstrapCheckboxComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicBootstrapCheckboxComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapCheckboxComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapCheckboxComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapCheckboxComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicCheckboxModel)
], DynamicBootstrapCheckboxComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapCheckboxComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapCheckboxComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapCheckboxComponent.prototype, "focus", void 0);
DynamicBootstrapCheckboxComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-checkbox",
        template: "<div [formGroup]=\"group\" [class.disabled]=\"model.disabled\" [ngClass]=\"getClass('element', 'control') || 'checkbox'\">\n\n    <label>\n\n        <input type=\"checkbox\"\n               [checked]=\"model.checked\"\n               [formControlName]=\"model.id\"\n               [id]=\"id\"\n               [indeterminate]=\"model.indeterminate\"\n               [name]=\"model.name\"\n               [ngClass]=\"getClass('element', 'control')\"\n               [required]=\"model.required\"\n               [tabindex]=\"model.tabIndex\"\n               [value]=\"model.value\"\n               (blur)=\"onBlur($event)\"\n               (change)=\"onChange($event)\"\n               (focus)=\"onFocus($event)\"/><span [innerHTML]=\"model.label\"\n                                                [ngClass]=\"[getClass('element', 'label'), getClass('grid', 'label')]\"></span></label>\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicBootstrapCheckboxComponent);

let DynamicBootstrapDatePickerComponent = class DynamicBootstrapDatePickerComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicBootstrapDatePickerComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapDatePickerComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapDatePickerComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapDatePickerComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicDatePickerModel)
], DynamicBootstrapDatePickerComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapDatePickerComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapDatePickerComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapDatePickerComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapDatePickerComponent.prototype, "focus", void 0);
__decorate([
    ViewChild(BsDatepickerDirective, { static: true }),
    __metadata("design:type", BsDatepickerDirective)
], DynamicBootstrapDatePickerComponent.prototype, "bsDatePicker", void 0);
DynamicBootstrapDatePickerComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-datepicker",
        template: "<div [formGroup]=\"group\" class=\"input-group\">\n\n    <input bsDatepicker class=\"form-control\" #bsDatepicker=\"bsDatepicker\"\n           [autofocus]=\"model.autoFocus\"\n           [bsConfig]=\"model.getAdditional('bsConfig', {containerClass: model.getAdditional('containerClass', 'theme-green'), showWeekNumbers: model.getAdditional('showWeekNumbers', true)})\"\n           [formControlName]=\"model.id\"\n           [id]=\"id\"\n           [maxDate]=\"model.max\"\n           [minDate]=\"model.min\"\n           [name]=\"model.name\"\n           [ngClass]=\"getClass('element', 'control')\"\n           [outsideClick]=\"model.getAdditional('outsideClick', true)\"\n           [placeholder]=\"model.placeholder\"\n           [placement]=\"model.getAdditional('placement', 'bottom')\"\n           [readonly]=\"model.readOnly\"\n           [required]=\"model.required\"\n           (bsValueChange)=\"onChange($event)\"\n           (onHidden)=\"onCustomEvent($event, 'onHidden')\"\n           (onShown)=\"onCustomEvent($event, 'onShown')\">\n\n    <div *ngIf=\"model.toggleLabel\" class=\"input-group-btn\">\n\n        <button *ngIf=\"model.toggleIcon\" class=\"btn\" (click)=\"bsDatepicker.toggle()\"><img [src]=\"model.toggleIcon\"/></button>\n        <button *ngIf=\"model.toggleLabel\" class=\"btn\" (click)=\"bsDatepicker.toggle()\">{{ model.toggleLabel }}</button>\n\n    </div>\n\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicBootstrapDatePickerComponent);

let DynamicBootstrapFormGroupComponent = class DynamicBootstrapFormGroupComponent extends DynamicFormGroupComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicBootstrapFormGroupComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapFormGroupComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapFormGroupComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapFormGroupComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormGroupModel)
], DynamicBootstrapFormGroupComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapFormGroupComponent.prototype, "templates", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormGroupComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormGroupComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormGroupComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormGroupComponent.prototype, "focus", void 0);
__decorate([
    ViewChildren(forwardRef(() => DynamicBootstrapFormControlContainerComponent)),
    __metadata("design:type", QueryList)
], DynamicBootstrapFormGroupComponent.prototype, "components", void 0);
DynamicBootstrapFormGroupComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-form-group",
        template: "<ng-container [formGroup]=\"group\">\n\n    <fieldset [formGroupName]=\"model.id\"\n              [id]=\"id\"\n              [name]=\"model.name\"\n              [ngClass]=\"getClass('element', 'control')\">\n\n        <legend *ngIf=\"model.legend\" [innerHTML]=\"model.legend\"></legend>\n\n        <dynamic-bootstrap-form-control *ngFor=\"let _model of model.group\"\n                                        [asBootstrapFormGroup]=\"false\"\n                                        [group]=\"control\"\n                                        [hidden]=\"_model.hidden\"\n                                        [layout]=\"formLayout\"\n                                        [model]=\"_model\"\n                                        [templates]=\"templates\"\n                                        [hostClass]=\"[getClass('element','children'), getClass('grid','children')]\"\n                                        (blur)=\"onBlur($event)\"\n                                        (change)=\"onChange($event)\"\n                                        (focus)=\"onFocus($event)\"\n                                        (bsEvent)=\"onCustomEvent($event, null, true)\"></dynamic-bootstrap-form-control>\n    </fieldset>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicBootstrapFormGroupComponent);

let DynamicBootstrapInputComponent = class DynamicBootstrapInputComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicBootstrapInputComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapInputComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapInputComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapInputComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicInputModel)
], DynamicBootstrapInputComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapInputComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapInputComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapInputComponent.prototype, "focus", void 0);
DynamicBootstrapInputComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-input",
        template: "<div [formGroup]=\"group\" [class.input-group]=\"model.prefix || model.suffix\">\n\n    <div *ngIf=\"model.prefix\" class=\"input-group-addon\" [innerHTML]=\"model.prefix\"></div>\n\n    <input class=\"form-control\"\n           [attr.accept]=\"model.accept\"\n           [attr.max]=\"model.max\"\n           [attr.min]=\"model.min\"\n           [attr.multiple]=\"model.multiple\"\n           [attr.step]=\"model.step\"\n           [autocomplete]=\"model.autoComplete\"\n           [autofocus]=\"model.autoFocus\"\n           [dynamicList]=\"model.listId\"\n           [formControlName]=\"model.id\"\n           [id]=\"id\"\n           [maxlength]=\"model.maxLength\"\n           [minlength]=\"model.minLength\"\n           [name]=\"model.name\"\n           [ngClass]=\"getClass('element', 'control')\"\n           [pattern]=\"model.pattern\"\n           [placeholder]=\"model.placeholder\"\n           [readonly]=\"model.readOnly\"\n           [required]=\"model.required\"\n           [spellcheck]=\"model.spellCheck\"\n           [tabindex]=\"model.tabIndex\"\n           [textMask]=\"{mask: (model.mask || false), showMask: model.mask && !(model.placeholder)}\"\n           [type]=\"model.inputType\"\n           (blur)=\"onBlur($event)\"\n           (change)=\"onChange($event)\"\n           (focus)=\"onFocus($event)\"/>\n\n    <div *ngIf=\"model.suffix\" class=\"input-group-addon\" [innerHTML]=\"model.suffix\"></div>\n\n    <datalist *ngIf=\"model.hasList\" [id]=\"model.listId\">\n\n        <option *ngFor=\"let option of model.list$ | async\" [value]=\"option\">\n\n    </datalist>\n\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicBootstrapInputComponent);

let DynamicBootstrapRadioGroupComponent = class DynamicBootstrapRadioGroupComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicBootstrapRadioGroupComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapRadioGroupComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapRadioGroupComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapRadioGroupComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicRadioGroupModel)
], DynamicBootstrapRadioGroupComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapRadioGroupComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapRadioGroupComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapRadioGroupComponent.prototype, "focus", void 0);
DynamicBootstrapRadioGroupComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-radio-group",
        template: "<fieldset role=\"radiogroup\"\n          [formGroup]=\"group\"\n          [id]=\"id\"\n          [name]=\"model.name\"\n          [ngClass]=\"getClass('element', 'control')\"\n          [tabindex]=\"model.tabIndex\"\n          (change)=\"onChange($event)\">\n\n    <legend *ngIf=\"model.legend\" [innerHTML]=\"model.legend\"></legend>\n\n    <div *ngFor=\"let option of model.options$ | async\" [ngClass]=\"getClass('element', 'option') || 'radio'\">\n\n        <label><input type=\"radio\"\n                      [formControlName]=\"model.id\"\n                      [name]=\"model.name\"\n                      [value]=\"option.value\"\n                      (blur)=\"onBlur($event)\"\n                      (focus)=\"onFocus($event)\"/><span [innerHTML]=\"option.label\"></span></label>\n    </div>\n\n</fieldset>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicBootstrapRadioGroupComponent);

let DynamicBootstrapRatingComponent = class DynamicBootstrapRatingComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicBootstrapRatingComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapRatingComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapRatingComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapRatingComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicRatingModel)
], DynamicBootstrapRatingComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapRatingComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapRatingComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapRatingComponent.prototype, "focus", void 0);
DynamicBootstrapRatingComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-rating",
        template: "<ng-container [formGroup]=\"group\">\n\n    <rating [formControlName]=\"model.id\"\n            [id]=\"id\"\n            [max]=\"model.max\"\n            [ngClass]=\"getClass('element', 'control')\"\n            [readonly]=\"model.getAdditional('readonly', false)\"\n            (onHover)=\"onCustomEvent($event, 'onHover')\"\n            (onLeave)=\"onCustomEvent($event, 'onLeave')\"></rating>\n\n</ng-container>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicBootstrapRatingComponent);

let DynamicBootstrapSelectComponent = class DynamicBootstrapSelectComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicBootstrapSelectComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapSelectComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapSelectComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapSelectComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicSelectModel)
], DynamicBootstrapSelectComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapSelectComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapSelectComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapSelectComponent.prototype, "focus", void 0);
DynamicBootstrapSelectComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-select",
        template: "<ng-container [formGroup]=\"group\">\n\n    <select class=\"form-control\"\n            [compareWith]=\"model.compareWithFn\"\n            [formControlName]=\"model.id\"\n            [id]=\"id\"\n            [name]=\"model.name\"\n            [ngClass]=\"getClass('element', 'control')\"\n            [required]=\"model.required\"\n            [tabindex]=\"model.tabIndex\"\n            (blur)=\"onBlur($event)\"\n            (change)=\"onChange($event)\"\n            (focus)=\"onFocus($event)\">\n\n        <option *ngFor=\"let option of model.options$ | async\"\n                [disabled]=\"option.disabled\"\n                [ngValue]=\"option.value\">{{ option.label }}\n        </option>\n\n    </select>\n\n</ng-container>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicBootstrapSelectComponent);

let DynamicBootstrapTextAreaComponent = class DynamicBootstrapTextAreaComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicBootstrapTextAreaComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapTextAreaComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapTextAreaComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapTextAreaComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicTextAreaModel)
], DynamicBootstrapTextAreaComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapTextAreaComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapTextAreaComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapTextAreaComponent.prototype, "focus", void 0);
DynamicBootstrapTextAreaComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-textarea",
        template: "<ng-container [formGroup]=\"group\">\n\n    <textarea class=\"form-control\"\n              [cols]=\"model.cols\"\n              [formControlName]=\"model.id\"\n              [id]=\"id\"\n              [maxlength]=\"model.maxLength\"\n              [minlength]=\"model.minLength\"\n              [name]=\"model.name\"\n              [ngClass]=\"getClass('element', 'control')\"\n              [placeholder]=\"model.placeholder\"\n              [readonly]=\"model.readOnly\"\n              [required]=\"model.required\"\n              [rows]=\"model.rows\"\n              [spellcheck]=\"model.spellCheck\"\n              [tabindex]=\"model.tabIndex\"\n              [wrap]=\"model.wrap\"\n              (blur)=\"onBlur($event)\"\n              (change)=\"onChange($event)\"\n              (focus)=\"onFocus($event)\"></textarea>\n\n</ng-container>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicBootstrapTextAreaComponent);

let DynamicBootstrapTimePickerComponent = class DynamicBootstrapTimePickerComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicBootstrapTimePickerComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapTimePickerComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapTimePickerComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapTimePickerComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicTimePickerModel)
], DynamicBootstrapTimePickerComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapTimePickerComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapTimePickerComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapTimePickerComponent.prototype, "focus", void 0);
__decorate([
    ViewChild(TimepickerComponent, { static: true }),
    __metadata("design:type", TimepickerComponent)
], DynamicBootstrapTimePickerComponent.prototype, "bsTimePicker", void 0);
DynamicBootstrapTimePickerComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-timepicker",
        template: "<ng-container [formGroup]=\"group\">\n\n    <timepicker [arrowkeys]=\"model.getAdditional('arrowkeys', true)\"\n                [formControlName]=\"model.id\"\n                [hourStep]=\"model.getAdditional('hourStep', 1)\"\n                [id]=\"id\"\n                [max]=\"model.max\"\n                [min]=\"model.min\"\n                [mousewheel]=\"model.getAdditional('mousewheel', true)\"\n                [minuteStep]=\"model.getAdditional('minuteStep', 1)\"\n                [ngClass]=\"getClass('element', 'control')\"\n                [secondsStep]=\"model.getAdditional('secondsStep', 1)\"\n                [showMeridian]=\"model.meridian\"\n                [showSeconds]=\"model.showSeconds\"\n                [showSpinners]=\"model.getAdditional('spinners', true)\"></timepicker>\n\n</ng-container>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicBootstrapTimePickerComponent);

let DynamicBootstrapFormControlContainerComponent = class DynamicBootstrapFormControlContainerComponent extends DynamicFormControlContainerComponent {
    constructor(changeDetectorRef, componentFactoryResolver, layoutService, validationService, componentService, relationService) {
        super(changeDetectorRef, componentFactoryResolver, layoutService, validationService, componentService, relationService);
        this.changeDetectorRef = changeDetectorRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.componentService = componentService;
        this.relationService = relationService;
        this.klass = "";
        this.asBootstrapFormGroup = true;
        this.context = null;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
        this.customEvent = new EventEmitter();
    }
    get componentType() {
        return this.componentService.getCustomComponentType(this.model) || bootstrapUIFormControlMapFn(this.model);
    }
};
DynamicBootstrapFormControlContainerComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ComponentFactoryResolver },
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: DynamicFormComponentService },
    { type: DynamicFormRelationService }
];
__decorate([
    ContentChildren(DynamicTemplateDirective),
    __metadata("design:type", QueryList)
], DynamicBootstrapFormControlContainerComponent.prototype, "contentTemplateList", void 0);
__decorate([
    HostBinding("class"),
    __metadata("design:type", Object)
], DynamicBootstrapFormControlContainerComponent.prototype, "klass", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapFormControlContainerComponent.prototype, "asBootstrapFormGroup", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormArrayGroupModel)
], DynamicBootstrapFormControlContainerComponent.prototype, "context", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapFormControlContainerComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], DynamicBootstrapFormControlContainerComponent.prototype, "hostClass", void 0);
__decorate([
    Input("templates"),
    __metadata("design:type", QueryList)
], DynamicBootstrapFormControlContainerComponent.prototype, "inputTemplateList", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapFormControlContainerComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormControlModel)
], DynamicBootstrapFormControlContainerComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormControlContainerComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormControlContainerComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormControlContainerComponent.prototype, "focus", void 0);
__decorate([
    Output("bsEvent"),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormControlContainerComponent.prototype, "customEvent", void 0);
__decorate([
    ViewChild("componentViewContainer", { read: ViewContainerRef, static: true }),
    __metadata("design:type", ViewContainerRef)
], DynamicBootstrapFormControlContainerComponent.prototype, "componentViewContainerRef", void 0);
DynamicBootstrapFormControlContainerComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-form-control",
        template: "<div [class.form-group]=\"asBootstrapFormGroup || getClass('element', 'container').includes('form-group')\"\n     [class.has-error]=\"showErrorMessages\"\n     [formGroup]=\"group\"\n     [ngClass]=\"['ng-dynamic-forms-'+model.type.toLowerCase(), getClass('element', 'container'), getClass('grid', 'container')]\">\n\n    <label *ngIf=\"!isCheckbox && hasLabel\"\n           [for]=\"id\"\n           [innerHTML]=\"model.label\"\n           [ngClass]=\"[getClass('element', 'label'), getClass('grid', 'label')]\"></label>\n\n    <ng-container *ngTemplateOutlet=\"startTemplate?.templateRef; context: model\"></ng-container>\n\n    <div [ngClass]=\"getClass('grid', 'control')\">\n\n        <ng-container #componentViewContainer></ng-container>\n\n        <span *ngIf=\"hasHint\" class=\"help-block\" [innerHTML]=\"hint\"\n              [ngClass]=\"getClass('element', 'hint')\"></span>\n\n    </div>\n\n    <ul *ngIf=\"showErrorMessages\" class=\"has-error\"\n        [ngClass]=\"[getClass('element', 'errors'), getClass('grid', 'errors')]\">\n\n        <li *ngFor=\"let message of errorMessages\" class=\"help-block\">{{ message }}</li>\n\n    </ul>\n\n    <ng-container *ngTemplateOutlet=\"endTemplate?.templateRef; context: model\"></ng-container>\n\n    <ng-content></ng-content>\n\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [ChangeDetectorRef,
        ComponentFactoryResolver,
        DynamicFormLayoutService,
        DynamicFormValidationService,
        DynamicFormComponentService,
        DynamicFormRelationService])
], DynamicBootstrapFormControlContainerComponent);
function bootstrapUIFormControlMapFn(model) {
    switch (model.type) {
        case DYNAMIC_FORM_CONTROL_TYPE_ARRAY:
            return DynamicBootstrapFormArrayComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX:
            return DynamicBootstrapCheckboxComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP:
            return DynamicBootstrapFormGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER:
            return DynamicBootstrapDatePickerComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_GROUP:
            return DynamicBootstrapFormGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_INPUT:
            return DynamicBootstrapInputComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP:
            return DynamicBootstrapRadioGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_RATING:
            return DynamicBootstrapRatingComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_SELECT:
            return DynamicBootstrapSelectComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA:
            return DynamicBootstrapTextAreaComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_TIMEPICKER:
            return DynamicBootstrapTimePickerComponent;
        default:
            return null;
    }
}

let DynamicBootstrapFormArrayComponent = class DynamicBootstrapFormArrayComponent extends DynamicFormArrayComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicBootstrapFormArrayComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapFormArrayComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapFormArrayComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapFormArrayComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormArrayModel)
], DynamicBootstrapFormArrayComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", QueryList)
], DynamicBootstrapFormArrayComponent.prototype, "templates", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormArrayComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormArrayComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormArrayComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormArrayComponent.prototype, "focus", void 0);
__decorate([
    ViewChildren(forwardRef(() => DynamicBootstrapFormControlContainerComponent)),
    __metadata("design:type", QueryList)
], DynamicBootstrapFormArrayComponent.prototype, "components", void 0);
DynamicBootstrapFormArrayComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-form-array",
        template: "<ng-container [formGroup]=\"group\">\n\n    <div [formArrayName]=\"model.id\" [id]=\"id\" [ngClass]=\"getClass('element', 'control')\">\n\n        <div *ngFor=\"let groupModel of model.groups; let idx = index\" role=\"group\"\n             [formGroupName]=\"idx\" [ngClass]=\"[getClass('element', 'group'), getClass('grid', 'group')]\">\n\n            <ng-container *ngTemplateOutlet=\"startTemplate?.templateRef; context: groupModel\"></ng-container>\n\n            <dynamic-bootstrap-form-control *ngFor=\"let _model of groupModel.group\"\n                                            [context]=\"groupModel\"\n                                            [group]=\"array.at(idx)\"\n                                            [hidden]=\"_model.hidden\"\n                                            [layout]=\"formLayout\"\n                                            [model]=\"_model\"\n                                            [templates]=\"templates\"\n                                            [hostClass]=\"[getClass('element','children'), getClass('grid','children')]\"\n                                            (blur)=\"onBlur($event)\"\n                                            (change)=\"onChange($event)\"\n                                            (focus)=\"onFocus($event)\"\n                                            (bsEvent)=\"onCustomEvent($event, null, true)\"></dynamic-bootstrap-form-control>\n\n            <ng-container *ngTemplateOutlet=\"endTemplate?.templateRef; context: groupModel\"></ng-container>\n\n        </div>\n\n    </div>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicBootstrapFormArrayComponent);

let DynamicBootstrapFormComponent = class DynamicBootstrapFormComponent extends DynamicFormComponent {
    constructor(changeDetectorRef, componentService) {
        super(changeDetectorRef, componentService);
        this.changeDetectorRef = changeDetectorRef;
        this.componentService = componentService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
        this.bsEvent = new EventEmitter();
    }
};
DynamicBootstrapFormComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DynamicFormComponentService }
];
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicBootstrapFormComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], DynamicBootstrapFormComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicBootstrapFormComponent.prototype, "layout", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormComponent.prototype, "focus", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicBootstrapFormComponent.prototype, "bsEvent", void 0);
__decorate([
    ContentChildren(DynamicTemplateDirective),
    __metadata("design:type", QueryList)
], DynamicBootstrapFormComponent.prototype, "templates", void 0);
__decorate([
    ViewChildren(DynamicBootstrapFormControlContainerComponent),
    __metadata("design:type", QueryList)
], DynamicBootstrapFormComponent.prototype, "components", void 0);
DynamicBootstrapFormComponent = __decorate([
    Component({
        selector: "dynamic-bootstrap-form",
        template: "<dynamic-bootstrap-form-control *ngFor=\"let controlModel of model; trackBy: trackByFn\"\n                                [group]=\"group\"\n                                [hidden]=\"controlModel.hidden\"\n                                [layout]=\"layout\"\n                                [model]=\"controlModel\"\n                                [templates]=\"templates\"\n                                (blur)=\"onBlur($event)\"\n                                (change)=\"onChange($event)\"\n                                (focus)=\"onFocus($event)\"\n                                (bsEvent)=\"onCustomEvent($event, bsEvent)\"></dynamic-bootstrap-form-control>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [ChangeDetectorRef,
        DynamicFormComponentService])
], DynamicBootstrapFormComponent);

let DynamicFormsBootstrapUIModule = class DynamicFormsBootstrapUIModule {
};
DynamicFormsBootstrapUIModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            ReactiveFormsModule,
            BsDatepickerModule,
            RatingModule,
            TimepickerModule,
            TextMaskModule,
            DynamicFormsCoreModule
        ],
        declarations: [
            DynamicBootstrapCheckboxComponent,
            DynamicBootstrapDatePickerComponent,
            DynamicBootstrapFormArrayComponent,
            DynamicBootstrapFormComponent,
            DynamicBootstrapFormControlContainerComponent,
            DynamicBootstrapFormGroupComponent,
            DynamicBootstrapInputComponent,
            DynamicBootstrapRadioGroupComponent,
            DynamicBootstrapRatingComponent,
            DynamicBootstrapSelectComponent,
            DynamicBootstrapTextAreaComponent,
            DynamicBootstrapTimePickerComponent
        ],
        entryComponents: [
            DynamicBootstrapCheckboxComponent,
            DynamicBootstrapDatePickerComponent,
            DynamicBootstrapFormArrayComponent,
            DynamicBootstrapFormGroupComponent,
            DynamicBootstrapInputComponent,
            DynamicBootstrapRadioGroupComponent,
            DynamicBootstrapRatingComponent,
            DynamicBootstrapSelectComponent,
            DynamicBootstrapTextAreaComponent,
            DynamicBootstrapTimePickerComponent
        ],
        exports: [
            DynamicFormsCoreModule,
            DynamicBootstrapCheckboxComponent,
            DynamicBootstrapDatePickerComponent,
            DynamicBootstrapFormArrayComponent,
            DynamicBootstrapFormComponent,
            DynamicBootstrapFormControlContainerComponent,
            DynamicBootstrapFormGroupComponent,
            DynamicBootstrapInputComponent,
            DynamicBootstrapRadioGroupComponent,
            DynamicBootstrapRatingComponent,
            DynamicBootstrapSelectComponent,
            DynamicBootstrapTextAreaComponent,
            DynamicBootstrapTimePickerComponent
        ]
    })
], DynamicFormsBootstrapUIModule);

/**
 * Generated bundle index. Do not edit.
 */

export { DynamicBootstrapCheckboxComponent, DynamicBootstrapDatePickerComponent, DynamicBootstrapFormArrayComponent, DynamicBootstrapFormComponent, DynamicBootstrapFormControlContainerComponent, DynamicBootstrapFormGroupComponent, DynamicBootstrapInputComponent, DynamicBootstrapRadioGroupComponent, DynamicBootstrapRatingComponent, DynamicBootstrapSelectComponent, DynamicBootstrapTextAreaComponent, DynamicBootstrapTimePickerComponent, DynamicFormsBootstrapUIModule, bootstrapUIFormControlMapFn };
//# sourceMappingURL=ui-bootstrap.js.map
